@@ -10,18 +10,17 @@ import (
 	"github.com/hetznercloud/hcloud-go/v2/hcloud"
 )
 
-var UpdateCmd = base.UpdateCmd{
+var UpdateCmd = base.UpdateCmd[*hcloud.Certificate]{
 	ResourceNameSingular: "Certificate",
 	ShortDescription:     "Update a Certificate",
 	NameSuggestions:      func(c hcapi2.Client) func() []string { return c.Firewall().Names },
-	Fetch: func(s state.State, _ *cobra.Command, idOrName string) (interface{}, *hcloud.Response, error) {
+	Fetch: func(s state.State, _ *cobra.Command, idOrName string) (*hcloud.Certificate, *hcloud.Response, error) {
 		return s.Client().Certificate().Get(s, idOrName)
 	},
 	DefineFlags: func(cmd *cobra.Command) {
 		cmd.Flags().String("name", "", "Certificate Name")
 	},
-	Update: func(s state.State, _ *cobra.Command, resource interface{}, flags map[string]pflag.Value) error {
-		certificate := resource.(*hcloud.Certificate)
+	Update: func(s state.State, _ *cobra.Command, certificate *hcloud.Certificate, flags map[string]pflag.Value) error {
 		updOpts := hcloud.CertificateUpdateOpts{
 			Name: flags["name"].String(),
 		}
