@@ -9,16 +9,15 @@ import (
 	"github.com/hetznercloud/hcloud-go/v2/hcloud"
 )
 
-var DeleteCmd = base.DeleteCmd{
+var DeleteCmd = base.DeleteCmd[*hcloud.SSHKey]{
 	ResourceNameSingular: "SSH Key",
 	ResourceNamePlural:   "SSH Keys",
 	ShortDescription:     "Delete an SSH Key",
 	NameSuggestions:      func(c hcapi2.Client) func() []string { return c.SSHKey().Names },
-	Fetch: func(s state.State, _ *cobra.Command, idOrName string) (interface{}, *hcloud.Response, error) {
+	Fetch: func(s state.State, _ *cobra.Command, idOrName string) (*hcloud.SSHKey, *hcloud.Response, error) {
 		return s.Client().SSHKey().Get(s, idOrName)
 	},
-	Delete: func(s state.State, _ *cobra.Command, resource interface{}) (*hcloud.Action, error) {
-		sshKey := resource.(*hcloud.SSHKey)
+	Delete: func(s state.State, _ *cobra.Command, sshKey *hcloud.SSHKey) (*hcloud.Action, error) {
 		_, err := s.Client().SSHKey().Delete(s, sshKey)
 		return nil, err
 	},
