@@ -7,7 +7,6 @@ import (
 
 	"github.com/hetznercloud/cli/internal/cmd/base"
 	"github.com/hetznercloud/cli/internal/cmd/cmpl"
-	"github.com/hetznercloud/cli/internal/cmd/experimental"
 	"github.com/hetznercloud/cli/internal/hcapi2"
 	"github.com/hetznercloud/cli/internal/state"
 )
@@ -48,5 +47,4 @@ var DisableSnapshotPlanCmd = base.Cmd{
 		cmd.Printf("Snapshot Plan disabled for Storage Box %d\n", storageBox.ID)
 		return nil
 	},
-	Experimental: experimental.StorageBoxes,
 }
