@@ -4,7 +4,6 @@ import (
 	"fmt"
 
 	"github.com/hetznercloud/cli/internal/cmd/base"
-	"github.com/hetznercloud/cli/internal/cmd/experimental"
 	"github.com/hetznercloud/cli/internal/hcapi2"
 	"github.com/hetznercloud/cli/internal/state"
 	"github.com/hetznercloud/hcloud-go/v2/hcloud"
@@ -39,5 +38,4 @@ var LabelCmds = base.LabelCmds[*hcloud.StorageBox]{
 	GetIDOrName: func(storageBox *hcloud.StorageBox) string {
 		return storageBox.Name
 	},
-	Experimental: experimental.StorageBoxes,
 }
