@@ -35,6 +35,6 @@ func TestResetPassword(t *testing.T) {
 	out, errOut, err := fx.Run(cmd, args)
 
 	require.NoError(t, err)
-	assert.Equal(t, ExperimentalWarning, errOut)
+	assert.Empty(t, errOut)
 	assert.Equal(t, "Password of Storage Box 123 reset\n", out)
 }
