@@ -7,7 +7,6 @@ import (
 
 	"github.com/hetznercloud/cli/internal/cmd/base"
 	"github.com/hetznercloud/cli/internal/cmd/cmpl"
-	"github.com/hetznercloud/cli/internal/cmd/experimental"
 	"github.com/hetznercloud/cli/internal/hcapi2"
 	"github.com/hetznercloud/cli/internal/state"
 	"github.com/hetznercloud/hcloud-go/v2/hcloud"
@@ -42,5 +41,4 @@ var DeleteCmd = base.DeleteCmd[*hcloud.StorageBoxSnapshot]{
 		result, _, err := s.Client().StorageBox().DeleteSnapshot(s, snapshot)
 		return result.Action, err
 	},
-	Experimental: experimental.StorageBoxes,
 }
