@@ -3,7 +3,6 @@ package snapshot
 import (
 	"github.com/spf13/cobra"
 
-	"github.com/hetznercloud/cli/internal/cmd/experimental"
 	"github.com/hetznercloud/cli/internal/cmd/util"
 	"github.com/hetznercloud/cli/internal/state"
 )
@@ -26,5 +25,5 @@ func NewCommand(s state.State) *cobra.Command {
 		LabelCmds.RemoveCobraCommand(s),
 		DeleteCmd.CobraCommand(s),
 	)
-	return experimental.StorageBoxes(s, cmd)
+	return cmd
 }
