@@ -39,6 +39,6 @@ func TestResetPassword(t *testing.T) {
 	out, errOut, err := fx.Run(cmd, args)
 
 	require.NoError(t, err)
-	assert.Equal(t, ExperimentalWarning, errOut)
+	assert.Empty(t, errOut)
 	assert.Equal(t, "Password of Storage Box Subaccount 456 reset\n", out)
 }
