@@ -8,7 +8,6 @@ import (
 
 	"github.com/hetznercloud/cli/internal/cmd/base"
 	"github.com/hetznercloud/cli/internal/cmd/cmpl"
-	"github.com/hetznercloud/cli/internal/cmd/experimental"
 	"github.com/hetznercloud/cli/internal/hcapi2"
 	"github.com/hetznercloud/cli/internal/state"
 	"github.com/hetznercloud/hcloud-go/v2/hcloud"
@@ -57,5 +56,4 @@ var UpdateCmd = base.UpdateCmd[*hcloud.StorageBoxSubaccount]{
 		}
 		return nil
 	},
-	Experimental: experimental.StorageBoxes,
 }
