@@ -32,6 +32,6 @@ func TestUpdateName(t *testing.T) {
 	expOut := "Storage Box 123 updated\n"
 
 	require.NoError(t, err)
-	assert.Equal(t, ExperimentalWarning, errOut)
+	assert.Empty(t, errOut)
 	assert.Equal(t, expOut, out)
 }
